@@ -2,32 +2,34 @@
 #
 # See the file license.txt for copying permission.
 
-import anyio
+import copy
 import logging
 import ssl
-import copy
-from urllib.parse import urlparse, urlunparse
 from functools import wraps
 from typing import Union
+from urllib.parse import urlparse, urlunparse
+
+import anyio
 
 try:
     from contextlib import asynccontextmanager
 except ImportError:
     from async_generator import asynccontextmanager
-from wsproto.utilities import ProtocolError
+
 from asyncwebsockets import create_websocket
+from moat.util import create_queue
+from wsproto.utilities import ProtocolError
 
-from .utils import match_topic, create_queue
-from .session import Session
-from .errors import NoDataException
-from .mqtt.connack import CONNECTION_ACCEPTED, CLIENT_ERROR
-from .mqtt.protocol.client_handler import ClientProtocolHandler
-from .adapters import StreamAdapter, WebSocketsAdapter
-from .plugins.manager import PluginManager, BaseContext
-from .mqtt.protocol.handler import ProtocolHandlerException
-from .mqtt.constants import QOS_0, QOS_1, QOS_2
 from . import codecs
-
+from .adapters import StreamAdapter, WebSocketsAdapter
+from .errors import NoDataException
+from .mqtt.connack import CLIENT_ERROR, CONNECTION_ACCEPTED
+from .mqtt.constants import QOS_0, QOS_1, QOS_2
+from .mqtt.protocol.client_handler import ClientProtocolHandler
+from .mqtt.protocol.handler import ProtocolHandlerException
+from .plugins.manager import BaseContext, PluginManager
+from .session import Session
+from .utils import match_topic
 
 _defaults = {
     "keep_alive": 10,
@@ -229,8 +231,6 @@ class MQTTClient:
 
         At first, a network connection is established with the server using the given protocol (``mqtt``, ``mqtts``, ``ws`` or ``wss``). Once the socket is connected, a `CONNECT <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718028>`_ message is sent with the requested informations.
 
-        This method is a *coroutine*.
-
         :param uri: Broker URI connection, conforming to `MQTT URI scheme <https://github.com/mqtt/mqtt.github.io/wiki/URI-Scheme>`_. Uses ``uri`` config attribute by default.
         :param cleansession: MQTT CONNECT clean session flag
         :param cafile: server certificate authority file (optional, used for secured connection)
@@ -259,8 +259,6 @@ class MQTTClient:
         Disconnect from the connected broker.
 
         This method sends a `DISCONNECT <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718090>`_ message and closes the network socket.
-
-        This method is a *coroutine*.
         """
 
         # do not reconnect any more
@@ -275,7 +273,7 @@ class MQTTClient:
             await self._handler.stop()
             self.session.transitions.disconnect()
         else:
-            self.logger.warning("Client session is not currently connected, ignoring call")
+            self.logger.info("Client session is not currently connected, ignoring Disconnect call")
 
     def cancel_tasks(self):
         """
@@ -293,8 +291,6 @@ class MQTTClient:
         Reconnection tries to establish a network connection and send a `CONNECT <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718028>`_ message.
         Retries interval and attempts can be controled with the ``reconnect_max_interval`` and ``reconnect_retries`` configuration parameters.
 
-        This method is a *coroutine*.
-
         :param cleansession: clean session flag used in MQTT CONNECT messages sent for reconnections.
         :return: `CONNACK <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718033>`_ return code
         :raise: :class:`moat.mqtt.client.ConnectException` if re-connection fails after max retries.
@@ -324,7 +320,7 @@ class MQTTClient:
                     raise ConnectException(  # pylint: disable=W0707
                         "Too many connection attempts failed"
                     )
-                exp = 2 ** nb_attempt
+                exp = 2**nb_attempt
                 delay = exp if exp < reconnect_max_interval else reconnect_max_interval
                 self.logger.debug("Waiting %d second before next attempt", delay)
                 await anyio.sleep(delay)
@@ -343,8 +339,6 @@ class MQTTClient:
         Ping the broker.
 
         Send a MQTT `PINGREQ <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718081>`_ message for response.
-
-        This method is a *coroutine*.
         """
 
         if self.session.transitions.is_connected():
@@ -362,8 +356,6 @@ class MQTTClient:
 
         Send a MQTT `PUBLISH <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718037>`_ message and wait for acknowledgment depending on Quality Of Service
 
-        This method is a *coroutine*.
-
         :param topic: topic name to which message data is published
         :param message: payload message (as bytes) to send.
         :param qos: requested publish quality of service : QOS_0, QOS_1 or QOS_2. Defaults to ``default_qos`` config parameter or QOS_0.
@@ -397,8 +389,6 @@ class MQTTClient:
 
         Send a MQTT `SUBSCRIBE <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718063>`_ message and wait for broker acknowledgment.
 
-        This method is a *coroutine*.
-
         :param topics: array of topics pattern to subscribe with associated QoS.
         :return: `SUBACK <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718068>`_ message return code.
 
@@ -412,22 +402,23 @@ class MQTTClient:
         """
         return await self._handler.mqtt_subscribe(topics, self.session.next_packet_id)
 
-    @mqtt_connected
     async def unsubscribe(self, topics):
         """
         Unsubscribe from some topics.
 
         Send a MQTT `UNSUBSCRIBE <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718072>`_ message and wait for broker `UNSUBACK <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718077>`_ message.
 
-        This method is a *coroutine*.
-
         :param topics: array of topics to unsubscribe from.
 
         Example of ``topics`` argument expected structure:
         ::
 
             ['$SYS/broker/uptime', '$SYS/broker/load/#']
+
+        This is a no-op if the client is not connected.
         """
+        if not self._connected_state.is_set():
+            return
         await self._handler.mqtt_unsubscribe(topics, self.session.next_packet_id)
 
     def subscription(self, topic, qos=QOS_0, codec=None):
@@ -583,8 +574,6 @@ class MQTTClient:
 
         Deliver next message received from the broker. If no message is available, this methods waits until next message arrives or ``timeout`` occurs.
 
-        This method is a *coroutine*.
-
         :return: instance of :class:`moat.mqtt.session.ApplicationMessage` containing received message information flow.
         :raises: :class:`TimeoutError` if timeout occurs before a message is delivered
 
@@ -701,6 +690,7 @@ class MQTTClient:
                 self.session.transitions.disconnect()
                 self.logger.warning("Connection rejected with code '%s'", return_code)
                 raise ConnectException("Connection rejected by broker", return_code)
+
             # Handle MQTT protocol
             await self._handler.start()
             self.session.transitions.connect()
@@ -806,7 +796,7 @@ class MQTTClient:
         else:
             s.clean_session = self.config.get("cleansession", True)
         s.keep_alive = self.config["keep_alive"] - self.config["ping_delay"]
-        if "will" in self.config:
+        if "will" in self.config and self.config["will"]["topic"]:
             s.will_flag = True
             s.will_retain = self.config["will"]["retain"]
             s.will_topic = self.config["will"]["topic"]
@@ -817,4 +807,5 @@ class MQTTClient:
             s.will_retain = False
             s.will_topic = None
             s.will_message = None
+            s.will_qos = 0
         return s
